Package: BioPlex
Title: R-side access to BioPlex protein-protein interaction data
Version: 1.15.0
Authors@R: 
    c(person("Ludwig", "Geistlinger",
             role = c("aut", "cre"),
             email = "ludwig_geistlinger@hms.harvard.edu"),
      person("Robert", "Gentleman",
             role = "aut"))
Description: The BioPlex package implements access to the BioPlex protein-protein
             interaction networks and related resources from within R. 
             Besides protein-protein interaction networks for HEK293 and HCT116 cells,
             this includes access to CORUM protein complex data, and transcriptome
             and proteome data for the two cell lines.  
             Functionality focuses on importing the various data resources and
             storing them in dedicated Bioconductor data structures, as a 
             foundation for integrative downstream analysis of the data. 
URL: https://github.com/ccb-hms/BioPlex
BugReports: https://github.com/ccb-hms/BioPlex/issues
Encoding: UTF-8
License: Artistic-2.0
VignetteBuilder: knitr
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.2.3
Depends: R (>= 4.1.0), SummarizedExperiment
Imports: BiocFileCache, GenomicRanges, GenomeInfoDb, GEOquery, graph,
        methods, utils
Suggests: AnnotationDbi, AnnotationHub, BiocStyle, DEXSeq,
        ExperimentHub, GenomicFeatures, S4Vectors, depmap, knitr,
        rmarkdown
biocViews: CellCulture, ColonCancerData, ExperimentHub, ExpressionData,
        GEO, Genome, Homo_sapiens_Data, MassSpectrometryData, Proteome,
        ReproducibleResearch, RNASeqData
git_url: https://git.bioconductor.org/packages/BioPlex
git_branch: devel
git_last_commit: fde35b2
git_last_commit_date: 2025-04-15
Repository: Bioconductor 3.22
Date/Publication: 2025-04-24
NeedsCompilation: no
Packaged: 2025-04-24 15:10:32 UTC; biocbuild
Author: Ludwig Geistlinger [aut, cre],
  Robert Gentleman [aut]
Maintainer: Ludwig Geistlinger <ludwig_geistlinger@hms.harvard.edu>

# Generated by roxygen2: do not edit by hand

export(annotatePFAM)
export(bioplex2graph)
export(ccleProteome2SummarizedExperiment)
export(corum2graphlist)
export(corum2list)
export(getBioPlex)
export(getBioplexProteome)
export(getCorum)
export(getGSE122425)
export(getHEK293GenomeTrack)
export(hasSubunit)
export(mapSummarizedExperimentOntoGraph)
import(SummarizedExperiment)
importFrom(methods,as)
importFrom(utils,download.file)
importFrom(utils,read.csv)
importFrom(utils,read.delim)
importFrom(utils,relist)
importFrom(utils,unzip)

############################################################
# 
# author: Ludwig Geistlinger
# date: 2021-02-16 09:20:02
# 
# descr: download CORUM data 
# 
############################################################

#' @title Obtain CORUM protein complex data
#' @description Functionality for retrieving the CORUM protein complex data.
#' Available complex collections include:
#' \itemize{
#' \item complete set of complexes,
#' \item core set of complexes,
#' \item complexes with splice variants.
#' } See references.
#' @param set character. Valid options include:
#' \itemize{ 
#' \item \code{"all"}: complete set of complexes,
#' \item \code{"core"}: core set of complexes,
#' \item \code{"splice"}: complexes with splice variants.
#' }
#' Defaults to \code{"all"}.
#' @param organism character. Use \code{NULL} to not subset by organism.
#' Defaults to \code{"Human"} which restricts the data to human protein complexes
#' only.
#' @param remap.uniprot.ids logical. Should the protein-to-gene mappings from CORUM
#' (i.e. UNIPROT-to-SYMBOL and UNIPROT-to-ENTREZID) be updated using Bioc annotation
#' functionality? Currently only supported in combination with \code{organism = "Human"}.
#' Defaults to \code{FALSE} which will then keep the mappings provided by CORUM.
#' @param cache logical. Should a locally cached version used if available?
#' Defaults to \code{TRUE}.
#' @param mode character. Should CORUM complexes be obtained from ExperimentHub 
#' or via a web download from the CORUM homepage? Defaults to \code{"ehub"}, 
#' which will obtain the chosen complex set from ExperimentHub. 
#' @return A \code{data.frame}. 
#' @references CORUM: \url{http://mips.helmholtz-muenchen.de/corum/#download}
#' @examples
#' # Obtain the core set of CORUM complexes
#' core <- getCorum(set = "core")
#' @importFrom utils download.file relist unzip
#' @export
getCorum <- function(set = c("all", "core", "splice"),
                     organism = "Human",
                     remap.uniprot.ids = FALSE,
                     cache = TRUE,
                     mode = c("ehub", "web"))
{
    set <- match.arg(set)
    mode <- match.arg(mode)
    if(mode == "ehub") corum <- .getCorumFromEH(set) 
    else corum <- .getCorumFromWeb(set, cache)

    # organism
    if(!is.null(organism))
    {
        stopifnot(organism %in% corum$Organism)
        corum <- subset(corum, Organism %in% organism)
    }
    
    # remap gene ids
    if(remap.uniprot.ids) corum <- .remapUniprotIds(corum)
    
    return(corum) 
}

.getCorumFromEH <- function(set)
{
    # obtain records from ExperimentHub
    eh <- ExperimentHub::ExperimentHub()
    recs <- AnnotationHub::query(eh, c("BioPlex", "CORUM"))

    suffix <- paste(set, "complexes", sep = "_")
    corum <- .getResource(recs, suffix)    
    return(corum)
}

.getCorumFromWeb <- function(set, cache)
{
    corum.url <- "http://mips.helmholtz-muenchen.de/corum/download"
    rname <- paste("corum", set, sep = "-")

    # should a cache version be used?
    if(cache) set.file <- .getResourceFromCache2(rname)
    if(!cache || is.null(set.file))        
    {
        set.file <- paste0(set, "Complexes.txt.zip")
        set.url <- file.path(corum.url, set.file)
        set.file <- .cacheResource2(rname, set.url)
    }

    # download, unzip, and read in
    set.file <- unzip(set.file, exdir = dirname(set.file))
    corum <- read.delim(set.file)
    file.remove(set.file)
    
    return(corum)
}

#' @title Represent CORUM protein complex data as a simple list
#' @description Functionality for storing CORUM protein complex data in a
#' \code{list}.
#' @param corum.df A \code{data.frame} storing the CORUM protein complex data.
#' Typically obtained via \code{\link{getCorum}}.
#' @param subunit.id.type character. Supported options include \code{"UNIPROT"}
#' (default) and \code{"ENTREZID"}.
#' @return A \code{list} with an entry for each complex. Each entry is a 
#' character vector of subunit IDs. 
#' @references CORUM: \url{http://mips.helmholtz-muenchen.de/corum/#download}
#' @examples
#'  # (1) Obtain the core set of CORUM complexes ...
#'  core <- getCorum(set = "core")
#'  
#'  # (2) ... turn into a list
#'  core.list <- corum2list(core)
#' @export
corum2list <- function(corum.df, 
                       subunit.id.type = c("UNIPROT", "ENTREZID"))
{
    stopifnot(is.data.frame(corum.df))
    subunit.id.type <- match.arg(subunit.id.type)
    subunit.id.type <- ifelse(subunit.id.type == "UNIPROT", "UniProt", "Entrez")
    id.col <- paste0("subunits.", subunit.id.type, ".IDs.")
    
    gs <- strsplit(corum.df[[id.col]], " ?; ?")
    complex.name <- gsub(" ", "_", corum.df$ComplexName)
    names(gs) <- paste0("CORUM", corum.df$ComplexID, "_", complex.name)
    return(gs)
}

#' @title Represent CORUM protein complex data as a list of graph instances
#' @description Functionality for storing CORUM protein complex data in a
#' \code{list} of \code{graph} instances.
#' @param corum.df A \code{data.frame} storing the CORUM protein complex data.
#' Typically obtained via \code{\link{getCorum}}.
#' @param subunit.id.type character. Supported options include \code{"UNIPROT"}
#' (default) and \code{"ENTREZID"}.
#' @return A \code{list} with an entry for each complex. Each entry is an 
#' object of class \code{graphNEL} connecting all subunit IDs with each other
#' by undirected edges. 
#' @references CORUM: \url{http://mips.helmholtz-muenchen.de/corum/#download}
#' @examples
#'  # (1) Obtain the core set of CORUM complexes ...
#'  core <- getCorum(set = "core")
#'  
#'  # (2) ... turn into a list of graphs
#'  core.glist <- corum2graphlist(core)
#' @export
corum2graphlist <- function(corum.df, 
                            subunit.id.type = c("UNIPROT", "ENTREZID"))
{
    cl <- corum2list(corum.df, subunit.id.type)
    gl <- lapply(cl, .completelyConnected)
    gl <- .annotateGraphList(gl, corum.df)
    return(gl)
}

#' @title Identify CORUM complexes that have a subunit of interest
#' @description Screens a \code{list} of \code{graph} instances storing 
#' CORUM protein complex data for a subunit of choice.
#' @param glist A \code{list} of \code{graph}s storing CORUM complexes.
#' Typically obtained via \code{\link{corum2graphlist}}. 
#' @param subunit character. A gene ID corresponding to the subunit of interest. 
#' @param id.type character. Gene ID type of the given subunit. Defaults to \code{"SYMBOL"}. 
#' @return A logical vector indicating which graphs have a node with the given 
#' subunit.
#' @examples
#' # (1) Obtain the core set of CORUM complexes ...
#' core <- getCorum(set = "core")
#' 
#' # (2) ... turn into a list of graphs ...
#' core.glist <- corum2graphlist(core)
#' 
#' # (3) .. check for a particular subunit of interest
#' has.cdk2 <- hasSubunit(core.glist, subunit = "CDK2")
#' @export
hasSubunit <- function(glist, subunit, id.type = "SYMBOL") 
{
    .hasX <- function(x) grep(subunit, 
                               unlist(graph::nodeData(x, graph::nodes(x), id.type)), 
                               ignore.case = TRUE)
    res <- lapply(glist, .hasX) 
    lengths(res) > 0
} 

.remapUniprotIds <- function(df)
{
    if(any(df$Organism != "Human")) 
        stop("Gene ID re-mapping is currently only supported for human")
    if(!requireNamespace("AnnotationHub"))
        stop("Please install the 'AnnotationHub' package for gene ID mapping")

    # relevant column names
    id.col <- "subunits.UniProt.IDs."
    eg.col <- "subunits.Entrez.IDs."
    sym.col <- "subunits.Gene.name."
    
    # obtain latest ensembl mappings from AnnotationHub
    suppressMessages({
        ah <- AnnotationHub::AnnotationHub()
        orgdb <- AnnotationHub::query(ah, c("orgDb", "Homo sapiens"))
        orgdb <- orgdb[[1]]
    })
    
    # map Uniprot IDs to Entrez IDs and to symbols
    unip <- strsplit(df[[id.col]], " ?; ?")
    ulnip <- unlist(unip)
    uunip <- unique(ulnip)
    
    suppressMessages({
        egs <- AnnotationDbi::mapIds(orgdb,
                                      keys = uunip,
                                      keytype = "UNIPROT",
                                      column = "ENTREZID")
        syms <- AnnotationDbi::mapIds(orgdb, 
                                      keys = uunip, 
                                      keytype = "UNIPROT", 
                                      column = "SYMBOL")
    })
    
    # replace corresponding columns in corum df
    egl <- relist(unname(egs[ulnip]), unip)
    df[[eg.col]] <- vapply(egl, paste, character(1), collapse = ";") 
    syl <- relist(unname(syms[ulnip]), unip)
    df[[sym.col]] <- vapply(syl, paste, character(1), collapse = ";")
    
    return(df)
}

# we will want to annotate these somewhat
#     ‘edgeData’: An ‘attrData’ instance for edge attributes.
#
#    ‘nodeData’: An ‘attrData’ instance for node attributes.
#
#    ‘graphData’: A ‘list’ for graph-level attributes. Only mandatory
#        list item is ‘edgemode’ which indicates whether edges are
#       ‘"directed"’ or ‘"undirected"’
#
.annotateGraphList <- function(glist, df)
{
    # FIXME: Someone needs to fix the graph class accessors for graph attributes
    #- we should not need to access the slot directly
    go.ids <- strsplit(df[["GO.ID"]], " ?; ?")
    entrez.ids <- strsplit(df[["subunits.Entrez.IDs."]], " ?; ?")
    symbols <- strsplit(df[["subunits.Gene.name."]], " ?; ?")
    for(i in seq_along(glist))
    {
        current <- glist[[i]]
        gd <- list(ComplexID = df[i, "ComplexID"],
                   ComplexName = df[i, "ComplexName"], 
                   GO.ID = go.ids[[i]], 
                   PubMed.ID = df[i, "PubMed.ID"])
        glist[[i]]@graphData <- c(current@graphData, gd)
        graph::nodeDataDefaults(glist[[i]], "ENTREZID") <- NA
        
        if(length(entrez.ids[[i]]) == graph::numNodes(current))
            graph::nodeData(glist[[i]], 
                            graph::nodes(glist[[i]]), 
                            "ENTREZID") <- entrez.ids[[i]]
        graph::nodeDataDefaults(glist[[i]], "SYMBOL") <- NA
        if(length(symbols[[i]]) == graph::numNodes(current))
            graph::nodeData(glist[[i]], 
                            graph::nodes(glist[[i]]), 
                            "SYMBOL") <- symbols[[i]]
        
    }
    return(glist)
}

# since our complexes are completely connected we will need a little
# helper function to create the instances
# @param nodes character vector of unique node names 
# @return instance of the graphNEL class where all nodes are connected 
# to all other nodes with undirected edges
.completelyConnected <- function(nodes) 
{
    if(!is.character(nodes)) stop("require character vector for nodes")
    if(length(nodes) == 0 ) stop("require at least one node")
    if(length(nodes) == 1 ) 
        return(graph::graphNEL(nodes = nodes, edgeL = list()))
    
    edL <- vector("list", length = length(nodes))
    names(edL) <- nodes
    eInds <- seq_along(nodes)
    for(i in eInds)
        edL[[i]] <- list(edges = eInds[-i])
    return(graph::graphNEL(nodes = nodes, edgeL = edL))
}

############################################################
# 
# author: Ludwig Geistlinger

# descr: misc utils
# 
############################################################

.cacheResource2 <- function(rname, fpath, ucdir = "BioPlex", ...)
{
    cache.dir <- tools::R_user_dir(ucdir, which = "cache")
    bfc <- BiocFileCache::BiocFileCache(cache.dir)
    
    # check if fpath is being tracked 
    qgsc <-  BiocFileCache::bfcquery(bfc, fpath)
    if(BiocFileCache::bfccount(qgsc) == 0) 
    {
        rpath <- BiocFileCache::bfcadd(bfc, rname, fpath, ...) 
    }
    else rpath <- qgsc$rpath
    return(rpath)
}

.getResourceFromCache2 <- function(rname, 
                                   update = TRUE,
                                   ucdir = "BioPlex",
                                   ...)
{
    cache.dir <- tools::R_user_dir(ucdir, which = "cache")
    bfc <- BiocFileCache::BiocFileCache(cache.dir)
    
    qgsc <-  BiocFileCache::bfcquery(bfc, rname, exact = TRUE)

    # is there already a cached version?
    res <- NULL
    if(BiocFileCache::bfccount(qgsc))
    {
        rid <- qgsc$rid
        
        # is the cached version outdated?
        nu <- FALSE
        if(update) nu <- BiocFileCache::bfcneedsupdate(bfc, rid)
        if(!isFALSE(nu)) BiocFileCache::bfcdownload(bfc, rid, ask = FALSE, ...)
        message("Using cached version from ", qgsc$create_time)
        res <- BiocFileCache::bfcrpath(bfc, rname)
    }
    return(res)   
}

############################################################
# 
# author: Ludwig Geistlinger
# date: 2021-02-26 08:22:09
# 
# descr: obtain CNV data for HEK293T and HCT116 cells
# 
############################################################

#' @title Obtain HEK293 genome data 
#'
#' @description Functionality for retrieving genomic data for different
#' lineages of the human embryonic kidney HEK293 cell line. 
#' Returned genomic coordinates are based on the *hg18* human genome assembly.
#' See references.
#' @param track character. Genome track to retrieve. Valid options include: 
#' \itemize{ 
#' \item \code{"cnvhmm"}: regions of copy number variation (CNV) as inferred by
#' a hidden Markov model (HMM) algorithm,
#' \item \code{"cnvsnp"}: CNV regions as inferred from Illumina SNP arrays
#' }
#' Defaults to \code{"cnvhmm"}.
#' @param cell.line character. Valid options include:
#' \itemize{ 
#' \item \code{"293T"}: highly-transfective derivative of human embryonic kidney
#' 293 cell line,
#' }
#' Defaults to \code{"293T"}.
#' @param cache logical. Should a locally cached version used if available?
#' Defaults to \code{TRUE}.
#' @return A \code{GRanges} object storing genomic coordinates and genomic scores
#' of regions of interest. 
#' @references \url{http://hek293genome.org}
#' @examples
#'    cnv.hmm <- getHEK293GenomeTrack(track = "cnv.hmm", cell.line = "293T")
#' 
#' @importFrom utils read.delim
#' @export
getHEK293GenomeTrack <- function(track = c("cnv.hmm", "cnv.snp"),
                                 cell.line = "293T",
                                 cache = TRUE)
{
    hek.url <- "http://bioinformatics.psb.ugent.be/downloads/genomeview/hek293"
    
    cell.line <- match.arg(cell.line)
    track <- match.arg(track)
    rname <- paste(cell.line, track, sep = ".")
 
    # should a cache version be used?
    if(cache) track.file <- .getResourceFromCache2(rname)
    if(!cache || is.null(track.file))    
    {   
        track <- switch(track,
            cnv.hmm = "CNV/cnv-293T-ALL.bed",
            cnv.snp = "SNP_array/T_chr_hg18.bed")

        track.file <- file.path(hek.url, track)
        track.file <- .cacheResource2(rname, track.file)
    }

    track <- read.delim(track.file, skip = 1, header = FALSE) 
    track <- track[,1:4]
    colnames(track) <- c("chr", "start", "end", "score")
    track <- GenomicRanges::makeGRangesFromDataFrame(track, keep.extra.columns = TRUE)
    GenomeInfoDb::genome(track) <- "hg18"
    return(track)
}

############################################################
# 
# author: Ludwig Geistlinger
# date: 2021-01-05 18:08:41
# 
# descr: misc utils
# 
############################################################

.cacheResource <- function(res, rname, ucdir="BioPlex")
{
    # are we running interactively?
    cache.dir <- tools::R_user_dir(ucdir, which = "cache")
    bfc <- BiocFileCache::BiocFileCache(cache.dir)
    
    # replace existing version if necessary 
    qgsc <-  BiocFileCache::bfcquery(bfc, rname, exact = TRUE)
    if(BiocFileCache::bfccount(qgsc)) BiocFileCache::bfcremove(bfc, qgsc$rid) 
    
    cache.file <- BiocFileCache::bfcnew(bfc, rname)
    saveRDS(res, file=cache.file)
}

.getResourceFromCache <- function(rname, 
    update.value=36, update.unit="weeks", ucdir="BioPlex")
{
    # are we running interactively?
    cache.dir <- tools::R_user_dir(ucdir, which = "cache")

    bfc <- BiocFileCache::BiocFileCache(cache.dir)
    qgsc <-  BiocFileCache::bfcquery(bfc, rname, exact = TRUE)

    # is there already a cached version?
    res <- NULL
    if(BiocFileCache::bfccount(qgsc))
    {
        # is the cached version outdated?
        dt <- difftime(Sys.time(), qgsc$create_time, units=update.unit)   
        if(is.na(update.value) || dt < update.value)
        {
            message("Using cached version from ", qgsc$create_time)
            res <- readRDS(BiocFileCache::bfcrpath(bfc, rname))
        }
    }
    return(res)   
}

.getResource <- function(recs, suffix)
{
    suffix <- paste0(suffix, "$")
    ind <- grep(suffix, recs$title)
    id <- recs$ah_id[ind]
    suppressMessages(rec <- recs[[id]])
    return(rec)
}

############################################################
# 
# author: Ludwig Geistlinger
# date: 2021-03-31 14:53:50
# 
# descr: utilities for obtaining & analysing proteome data 
# 
############################################################

#' @title Convenient access to the CCLE proteome data
#' @description Functionality for storing the protein expression data
#' from the Cancer Cell Line Encyclopedia (CCLE) in a 
#' \code{\linkS4class{SummarizedExperiment}}.
#' @param df a \code{data.frame} storing the CCLE protein expression data with
#' one measurement in each row. Typically obtained from \code{ExperimentHub}.
#' See examples. 
#' @param cell.line character. One or more cell line IDs such as \code{"HCT116"}
#' (human colon cancer cell line 116). Use \code{NULL} to not subset by cell line.
#' Defaults to \code{"HCT116"}, which will then subset the df to measurements for
#' HCT116 only.
#' @return A \code{\linkS4class{SummarizedExperiment}} storing protein expression
#' data for the specified cell line(s). 
#' @references CCLE proteomics: \url{https://gygi.hms.harvard.edu/publications/ccle.html}
#' @examples
#' 
#'   # Connect to ExperimentHub
#'   eh <- ExperimentHub::ExperimentHub()
#'
#'   # Obtain CCLE proteome data frame
#'   AnnotationHub::query(eh, c("gygi", "depmap"))
#'   ccle.prot <- eh[["EH3459"]]
#'   ccle.prot <- as.data.frame(ccle.prot)
#'
#'   # Turn into a SummarizedExperiment
#'   se <- ccleProteome2SummarizedExperiment(ccle.prot)
#'   
#' @export
ccleProteome2SummarizedExperiment <- function(df, cell.line = "HCT116")
{
    ids <- strsplit(df[,"cell_line"], "_")
    ids <- vapply(ids, `[`, character(1), x = 1)
  
    # subset by specific cell lines?
    if(!is.null(cell.line))
    {
        ind <- ids %in% cell.line
        sdiff <- setdiff(cell.line, unique(ids))
        if(length(sdiff)) warning("Ignoring invalid cell lines ", 
                                  paste(sdiff, collapse = ", "))
        df <- df[ind,]
        ids <- ids[ind]
    }

    # split + extract by cell line
    df.spl <- split(df, ids)
    
    # first: some sanity checks on dimensions and UNIPROT IDs
    nrows <- vapply(df.spl, nrow, integer(1))
    ind <- nrows == nrows[1]
    if(!all(ind)) df.spl <- df.spl[ind]
    unip <- vapply(df.spl, 
                   function(x) x[,"uniprot_acc"],
                   character(nrows[1]))
    uids <- apply(unip, 1, unique)
    stopifnot(is.character(uids))
    
    # second: pull out expression and metadata separately 
    pexpr <- vapply(df.spl, 
                    function(x) x[,"protein_expression"],
                    numeric(nrows[1]))
    rownames(pexpr) <- uids
    
    # store in SE
    se <- SummarizedExperiment(assays = list(expr = pexpr))
    rel.cols <- c("gene_name", "entrez_id")
    rowData(se) <- df.spl[[1]][,rel.cols]
    colnames(rowData(se)) <- c("SYMBOL", "ENTREZID")
    
    return(se)
}

#' @title Obtain BioPlex3 proteome data
#' @description Functionality for retrieving the BioPlex3 protein expression 
#' data comparing expression in the HCT116 and the 293T cell lines.
#' @param cache logical. Should a locally cached version used if available?
#' Defaults to \code{TRUE}.
#' @return A \code{\linkS4class{SummarizedExperiment}} storing protein expression
#' data for the both cell line(s) with 5 replicates each. 
#' @references BioPlex: \url{https://bioplex.hms.harvard.edu}
#' @examples
#' 
#'   se <- getBioplexProteome()
#'   
#' @importFrom utils read.csv
#' @export
getBioplexProteome <- function(cache = TRUE)
{
    bioplex.url <- file.path("https://bioplex.hms.harvard.edu/data", 
                             "293T_HCT116_ProteomeComparison.tsv")

    # should a cached version be used?
    rname <- "bp.prot"
    if(cache) se.file <- .getResourceFromCache2(rname, FUN = .bp2se)
    if(!cache || is.null(se.file))
    {
        se.file <- .cacheResource2(rname, bioplex.url,
                                   download = FALSE, ext = ".rds")
        se.file <- suppressMessages(.getResourceFromCache2(rname, FUN = .bp2se))
    }
    se <- readRDS(se.file)
    return(se)
}

.bp2se <- function(from, to)
{
    # read and extract the data
    dat <- read.delim(from)
    ind <- grep("scaled$", colnames(dat))
    emat <- dat[,ind]
    
    ids <- strsplit(dat[,"Protein.Id"], "\\|")
    ids <- vapply(ids, `[`, character(1), x = 2)
    rownames(emat) <- ids
    colnames(emat) <- sub(".scaled$", "", colnames(emat))
    emat <- as.matrix(emat)
    
    # turn into a SummarizedExperiment
    se <- SummarizedExperiment(assays = list(exprs = emat))
    se$cell.line <- rep(c("HCT116", "293T"), each = 5)
    rcols <- c("GeneID", "Gene.Symbol", "X..Peps", "Log2ratio", "AdjPValue")
    rowData(se) <- dat[,rcols]
    colnames(rowData(se)) <- c("ENTREZID", "SYMBOL", 
                               "nr.peptides", "log2ratio", "adj.pvalue")
    rowData(se)$ENTREZID <- as.character(rowData(se)$ENTREZID)
    saveRDS(se, file = to)
    return(TRUE)
}

############################################################
# 
# author: Ludwig Geistlinger
# date: 2021-02-16 13:09:57
# 
# descr: obtain and clean transcriptome data from GEO
#        for HEK293 and HCT116 cells
# 
############################################################

#' @title Convenient access to 293T transcriptome data from GEO
#' @description Functionality for storing the 293T RNA-seq data
#' from GSE122425 in a 
#' \code{\linkS4class{SummarizedExperiment}}. The dataset includes three
#' wild type samples and three NSUN2 knockout samples.
#' @param cache logical. Should a locally cached version used if available?
#' Defaults to \code{TRUE}.
#' @return A \code{\linkS4class{SummarizedExperiment}} storing RNA-seq
#' data for the 293T cell line. 
#' @references GSE122425: \url{https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE122425}
#' @examples
#' 
#'   # Obtain the data as a SummarizedExperiment
#'   se <- getGSE122425()
#'  
#' @import SummarizedExperiment
#' @importFrom methods as
#' @export
getGSE122425 <- function(cache = TRUE)
{
    rname <- "GSE122425"
    stub <- gsub("\\d{1,3}$", "nnn", rname, perl = TRUE)
    url <- sprintf("https://ftp.ncbi.nlm.nih.gov/geo/series/%s/%s/suppl/", stub, rname)
    count.file <- paste0(rname, "_all.counts.293_vs_293NK.edgeR_all.xls.gz")
    url <- paste0(url, count.file)   

    # should a cached version be used
    if(cache) se.file <- .getResourceFromCache2(rname,
                                                update = FALSE,
                                                FUN = .gse2se)
    if(!cache || is.null(se.file))
    {
        se.file <- .cacheResource2(rname, url, download = FALSE, ext = ".rds")
        se.file <- suppressMessages(.getResourceFromCache2(rname, FUN = .gse2se))
    }
    se <- readRDS(se.file)
    return(se)
}

.gse2se <- function(from, to)
{
    # pull from GEO
    eset <- GEOquery::getGEO("GSE122425")[[1]]
    se <- as(eset, "SummarizedExperiment")
    
    # expression data not well formated, ...
    # we need to pull the supplementary files to get the counts
    # NOTE: .xls extension is errorneous, it's actually a .tsv file
    cont <- read.delim(from)  

    # we have raw counts and rpkms here in one matrix, ...
    # let's pull them out separately and make each one an assay
    ind <- rep("HEK293", 6)
    ind[4:6] <- paste0(ind[4:6], "NK")
    ind <- paste(ind, "SEQ", sep = ".")
    ind <- paste0(ind, rep(seq_len(3), 2)) 

    raw <- as.matrix(cont[,ind])    
    ind <- paste(ind, "RPKM", sep = "_")
    rpkm <- as.matrix(cont[,ind])    

    colnames(raw) <- colnames(rpkm) <- colnames(se)
    rownames(raw) <- rownames(rpkm) <- cont$gene_id

    # store in an SE
    cdat <- colData(se)
    se <- SummarizedExperiment::SummarizedExperiment(assays = list(raw = raw,
                                                     rpkm = rpkm),
                                                     colData = cdat)
    anno.cols <- c("GeneSymbol", "KO", "GO", "length")
    rowData(se) <- cont[,anno.cols] 
    colnames(rowData(se))[1] <- "SYMBOL"

    saveRDS(se, file = to)
    return(TRUE)
}

library(graphframes)
library(sparklyr)
library(dplyr)

# Set environ vars
Sys.setenv(SPARK_HOME = '/home/chw925/spark/spark-2.1.0-bin-hadoop2.7/')

# Configure cluster
conf <- spark_config()
conf$spark.executor.cores <- 4
conf$spark.executor.memory <- "20G"
conf$spark.yarn.am.cores  <- 2
conf$spark.yarn.am.memory <- "20G"

# Start spark session
sc <- spark_connect(master = "yarn-client", version = "2.1.0", config = conf)

infile_293t <- "/n/shared_db/ccb/bioplex/data/protein_interactions/BioPlex_293T_Network_10K_Dec_2019.tsv"
df_293t <- spark_read_csv(sc, infile_293t, delimiter="\t")

# "from" vertices
from_tbl <- df_293t %>%
    distinct(SymbolA) %>%
    transmute(id = SymbolA)

# "to" vertices
to_tbl <- df_293t %>%
    distinct(SymbolB) %>%
    transmute(id = SymbolB)

# Union of to and from veritices
vertices_tbl <- from_tbl %>%
    sdf_bind_rows(to_tbl)

# Edges
edges_tbl <- df_293t %>%
    transmute(src = SymbolA, dst = SymbolB)
#sdf_num_partitions(edges_tbl)

# Create graphframe
gf <- gf_graphframe(vertices_tbl, edges_tbl)

# Calculate page rank
pgrank <- gf %>%
    gf_pagerank(reset_prob = 0.15, max_iter = 10L, source_id = "ACADVL")
head(pgrank)

# Calculate vertex degrees
#degrees <- gf %>%
#    gf_degrees()
#head(degrees)

############################################################
# 
# author: Ludwig Geistlinger
# date: 2022-07-13 15:24:52
# 
# descr: construction of HEK293T_HCT116_exon_counts 
#        DEXSeqDataSet from GEO 
# 
############################################################

# RNA-seq data for HEK293T cells was obtained from GEO accession GSE122633
# (runs labeled UnTfx1, UnTfx2 and UnTfx3 were used as those assayed untransformed
# wild type HEK293T cells)

# RNA-seq data for HCT116 cells was obtained from GEO accession GSE52429 
# (runs labeled repPF and repPJ were used as those assayed untransformed wild type
# HCT116 cells)

# The reads were aligned to the GRCh38.104 genome by STAR 2.7.9a 
# and counted by DEXseq 1.42.0.

# The resulting DEXSeqDataSet was filtered to exclude genes for which all exons
# have zero read counts using the following code:
# ("dxd" is the name of the DEXSeqDataSet)

library(DEXSeq)
rs <- rowSums(assay(dxd)[,1:5])
all.zero <- unname(rs) == 0
spl <- split(all.zero, rowData(dxd)$groupID)
all.zero <- vapply(spl, all, logical(1))
all.zero <- names(spl)[all.zero]

ind <- rowData(dxd)$groupID %in% all.zero
dxd <- dxd[!ind,]

############################################################
# 
# author: Ludwig Geistlinger
# date: 2021-02-26 08:22:09
# 
# descr: obtain BioPlex PPIs
# 
############################################################

#' @title Obtain BioPlex protein-protein interaction data
#' @description Functionality for retrieving the BioPlex protein-protein
#' interaction data. Available networks include:
#' \itemize{
#' \item BioPlex 293T cells (versions 1.0, 2.0, and 3.0), 
#' \item BioPlex HCT116 cells (version 1.0).
#' } See references.
#' @param cell.line character. Valid options include:
#' \itemize{ 
#' \item \code{"293T"}: derivative of human embryonic kidney 293 cell line,
#' \item \code{"HCT116"}: human colon cancer cell line 116.
#' }
#' Defaults to \code{"293T"}.
#' @param version character. Valid options include \code{"1.0"}, \code{"2.0"},
#' and \code{"3.0"} for 293T cells. For HCT116 cells, only \code{"1.0"} is 
#' available. 
#' Defaults to \code{"3.0"}.
#' @param remap.uniprot.ids logical. Should the protein-to-gene mappings from BioPlex
#' (i.e. UNIPROT-to-SYMBOL and UNIPROT-to-ENTREZID) be updated using Bioc annotation
#' functionality?
#' Defaults to \code{FALSE} which will then keep the mappings provided by BioPlex.
#' @param cache logical. Should a locally cached version used if available?
#' Defaults to \code{TRUE}.
#' @return A \code{data.frame}. 
#' @references BioPlex: \url{https://bioplex.hms.harvard.edu/interactions.php}
#' @examples
#' # (1) Obtain the latest version of the 293T PPI network
#' bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")
#' 
#' # (2) Obtain the latest version of the HCT116 PPI network
#' bp.hct116 <- getBioPlex(cell.line = "HCT116", version = "1.0")
#' @importFrom utils read.delim
#' @export
getBioPlex <- function(cell.line = c("293T", "HCT116"),
                       version = c("3.0", "1.0", "2.0"),
                       remap.uniprot.ids = FALSE,
                       cache = TRUE)
{
    bioplex.url <- "https://bioplex.hms.harvard.edu/data/BioPlex_"
  
    cell.line <- match.arg(cell.line)
    version <- match.arg(version)
    
    # we only have version 1.0 for HCT116 cells currently
    if(cell.line == "HCT116") version <- "1.0"
    
    clver <- paste(cell.line, version, sep = ".")
    rname <- paste("bioplex", clver, sep = ".")   
 
    # should a cache version be used?
    if(cache) ppi.file <- .getResourceFromCache2(rname)
    if(!cache || is.null(ppi.file))        
    {
        # get the data
        file.ext <- switch(clver,
                           `293T.1.0` = "interactionList_v2",
                           `293T.2.0` = "interactionList_v4a",
                           `293T.3.0` = "293T_Network_10K_Dec_2019",
                           `HCT116.1.0` = "HCT116_Network_5.5K_Dec_2019",
                           `293T.1.0d` = "1.0_293T_" )
        file.ext <- paste(file.ext, "tsv", sep = ".")
        ppi.file <- paste0(bioplex.url, file.ext)
        ppi.file <- .cacheResource2(rname, ppi.file)
    }
    
    bioplex <- read.delim(ppi.file)
    colnames(bioplex) <- c("GeneA", "GeneB",
                           "UniprotA", "UniprotB",
                           "SymbolA", "SymbolB",
                           "pW", "pNI", "pInt")
    bioplex$GeneA <- as.character(bioplex$GeneA)
    bioplex$GeneB <- as.character(bioplex$GeneB)
    
    # remap gene ids
    if(remap.uniprot.ids) bioplex <- .remapUniprotIdsBP(bioplex)
    
    # clean up & cache
    return(bioplex)
}

#' @title Representation of BioPlex PPIs in a graph data structure
#' @description Representation of BioPlex PPIs in a \code{graphNEL} object
#' from the \code{graph} package.
#' @param bioplex.df a \code{data.frame} storing the Bioplex PPIs in a flat
#' from-to format. Typically obtained via \code{\link{getBioPlex}}.
#' @return An object of class \code{graphNEL}. 
#' @references BioPlex: \url{https://bioplex.hms.harvard.edu/interactions.php}
#' @seealso \code{\link{getBioPlex}}, \code{\link{ftM2graphNEL}}
#' @examples
#' # (1) Obtain the latest version of the 293T PPI network
#' bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")
#' 
#' # (2) Turn the data into a graph 
#' bp.gr <- bioplex2graph(bp.293t)
#' 
#' @export
bioplex2graph <- function(bioplex.df) 
{
    stopifnot(is.data.frame(bioplex.df))
    node.cols <- paste0("Uniprot", c("A", "B"))
    ftm <- as.matrix(bioplex.df[,node.cols])
    ftm <- sub("-[0-9]+$", "", ftm)
    ind <- !duplicated(ftm)
    ftm <- ftm[ind,]
    bioplex.df <- bioplex.df[ind,]
    gr <- graph::ftM2graphNEL(ftm, edgemode = "directed")
    gr <- .annotateBioplexGraph(gr, bioplex.df)
    return(gr)
}



#' @title Annotate PFAM domains to BioPlex PPI graph
#' @description This function adds PFAM domain annotations to the node metadata
#' of the BioPlex PPI graph.
#' @param bp.gr an object of class \code{\linkS4class{graph}} storing the
#' BioPlex PPIs. Typically obtained via \code{\link{bioplex2graph}}.
#' @param orgdb an \code{orgdb} object storing annotation data for human.
#' @return An object of class \code{graphNEL} containing PFAM domain annotations
#' in the \code{nodeData}. 
#' @references 
#'  BioPlex: \url{https://bioplex.hms.harvard.edu/interactions.php}
#'
#'  PFAM: \url{http://pfam.xfam.org}
#' @seealso \code{\link{nodeData}}
#' @examples
#' # (1) Obtain the latest version of the 293T PPI network
#' bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")
#' 
#' # (2) Turn the data into a graph 
#' bp.gr <- bioplex2graph(bp.293t)
#' 
#' # (3) Obtain orgdb package from AnnotationHub
#' ah <- AnnotationHub::AnnotationHub()
#' orgdb <- AnnotationHub::query(ah, c("orgDb", "Homo sapiens"))
#' orgdb <- orgdb[[1]]
#' 
#' # (4) Annotate PFAM domains
#' bp.gr <- annotatePFAM(bp.gr, orgdb)
#'
#' @export
annotatePFAM <- function(bp.gr, orgdb)
{
  up2pfam <- suppressMessages(AnnotationDbi::mapIds(orgdb, 
                                   keys = graph::nodes(bp.gr), 
                                   keytype = "UNIPROT", 
                                   column = "PFAM", 
                                   multiVals = "list"))
  graph::nodeDataDefaults(bp.gr, "PFAM") <- NA
  graph::nodeData(bp.gr, graph::nodes(bp.gr), "PFAM") <- up2pfam
  return(bp.gr)
}

# we will want to annotate these somewhat
#     ‘edgeData’: An ‘attrData’ instance for edge attributes.
#
#    ‘nodeData’: An ‘attrData’ instance for node attributes.
#
#    ‘graphData’: A ‘list’ for graph-level attributes. Only mandatory
#        list item is ‘edgemode’ which indicates whether edges are
#       ‘"directed"’ or ‘"undirected"’
#
.annotateBioplexGraph <- function(gr, df)
{
    # create maps to annotate node data:
    # 1. uniprot -> symbol
    # 2. uniprot -> entrez
    ucols <- paste0("Uniprot", c("A", "B"))
    scols <- paste0("Symbol", c("A", "B"))
    ecols <- paste0("Gene", c("A", "B"))
    
    iids <- unlist(df[,ucols])
    sids <- unlist(df[,scols])
    eids <- unlist(df[,ecols])
    
    ind <- !duplicated(iids)
    iids <- iids[ind]
    uids <- sub("-[0-9]+$", "", iids)
    up2sym <- sids[ind]
    up2eg <- eids[ind]
    names(iids) <- names(up2eg) <- names(up2sym) <- uids
    
    # graph data annotation
    # when starting off with a ordinary dfs we'll be losing the ability
    # to annotate graph-level annotation such as cell.line, version, PMID, ...
    # we might need to work with DataFrames where we have mcols and metadata
    
    # node data annotation             
    graph::nodeDataDefaults(gr, "ENTREZID") <- NA
    graph::nodeData(gr, graph::nodes(gr), "ENTREZID") <- up2eg[graph::nodes(gr)]
    graph::nodeDataDefaults(gr, "SYMBOL") <- NA
    graph::nodeData(gr, graph::nodes(gr), "SYMBOL") <- up2sym[graph::nodes(gr)]
    graph::nodeDataDefaults(gr, "ISOFORM") <- NA
    graph::nodeData(gr, graph::nodes(gr), "ISOFORM") <- iids[graph::nodes(gr)]
    
    # edge data annotation
    for(col in ucols) df[,col] <- sub("-[0-9]+$", "", df[,col])
    for(col in c("pW", "pNI", "pInt"))
    {
        graph::edgeDataDefaults(gr, col) <- numeric(0L)
        graph::edgeData(gr, df[,ucols[1]], df[,ucols[2]], col) <- df[,col]
    }
      
    return(gr)
}

#' @title Map experimental data onto a graph
#' @description Functionality for mapping experimental data stored in
#' a \code{\linkS4class{SummarizedExperiment}} onto a 
#' \code{\linkS4class{graph}} object. 
#' @param gr an object of class \code{\linkS4class{graph}}.
#' @param se an object of class \code{\linkS4class{SummarizedExperiment}}.
#' @param col.names character. Column names of \code{se} for which assay
#' data should be mapped onto the nodes of \code{gr}. Defaults to \code{NULL}
#' which will then use all column names of \code{se}.
#' @param rowdata.cols character. Column names of \code{rowData(se)} which
#' should be mapped onto the nodes of \code{gr}. Defaults to \code{NULL}
#' which will then use all column names of \code{rowData(se)}.
#' @param prefix character. Informative prefix that should be pasted together
#' with the selected \code{col.names} and \code{rowdata.cols} to allow easy
#' identification of columns of interest when mapping from multiple experimental
#' datasets.
#' @return An object of class \code{\linkS4class{graph}}. 
#' @examples
#' # (1) Obtain the latest version of the 293T PPI network ...
#' bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")
#' 
#' # (2) ... and turn into a graph
#' bp.gr <- bioplex2graph(bp.293t)
#' 
#' # (3) Obtain the BioPlex3 proteome data ...
#' se <- getBioplexProteome()
#' 
#' # (4) ... and map onto the graph
#' bp.gr <- mapSummarizedExperimentOntoGraph(bp.gr, se)
#' @export
mapSummarizedExperimentOntoGraph <- function(gr, se,
                                             col.names = NULL,
                                             rowdata.cols = NULL,
                                             prefix = "")
{
    isect <- intersect(rownames(se), graph::nodes(gr))
    if(!length(isect)) stop("SummarizedExperiment (se)", " and ",
                            "graph (gr) have no node IDs in common")
    
    if(is.null(col.names)) col.names <- colnames(se)
    else if(!all(col.names %in% colnames(se)))
        stop("Invalid col.names provided")
      
    if(is.null(rowdata.cols)) rowdata.cols <- colnames(rowData(se))
    else if(!all(rowdata.cols %in% colnames(rowData(se))))
        stop("Invalid rowdata.cols provided")
    
    # map assay data onto nodes
    for(n in col.names)
    {  
        gn <- paste0(prefix, n)
        graph::nodeDataDefaults(gr, gn) <- NA
        graph::nodeData(gr, isect, gn) <- assay(se)[isect, n]
    }
    
    # map rowData onto nodes
    for(n in rowdata.cols)
    {  
        gn <- paste0(prefix, n)
        graph::nodeDataDefaults(gr, gn) <- NA
        graph::nodeData(gr, isect, gn) <- rowData(se)[isect, n]
    }
    return(gr)
}

.remapUniprotIdsBP <- function(df)
{
    stopifnot(is.data.frame(df))
    uids1 <- sub("-[0-9]+$", "", df$UniprotA)
    uids2 <- sub("-[0-9]+$", "", df$UniprotB)
    
    suppressMessages({
      ah <- AnnotationHub::AnnotationHub()
      orgdb <- AnnotationHub::query(ah, c("orgDb", "Homo sapiens"))
      orgdb <- orgdb[[1]]
    })
    
    suppressMessages({
      df$GeneA <- AnnotationDbi::mapIds(orgdb,
                                   keys = uids1,
                                   keytype = "UNIPROT",
                                   column = "ENTREZID")
      df$GeneB <- AnnotationDbi::mapIds(orgdb,
                                        keys = uids2,
                                        keytype = "UNIPROT",
                                        column = "ENTREZID")
      df$SymbolA <- AnnotationDbi::mapIds(orgdb, 
                                          keys = uids1, 
                                          keytype = "UNIPROT", 
                                          column = "SYMBOL")
      df$SymbolB <- AnnotationDbi::mapIds(orgdb, 
                                          keys = uids2, 
                                          keytype = "UNIPROT", 
                                          column = "SYMBOL")
    })
    
    return(df)
}

---
title: "Basic checks of BioPlex PPI data"
output:
  BiocStyle::html_document:
    self_contained: yes 
    toc: true
    toc_float: true
    toc_depth: 2
    code_folding: show
date: "`r doc_date()`"
package: "`r pkg_ver('BioPlex')`"
vignette: >
  % \VignetteIndexEntry{2. Data checks}
  % \VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL ## Related to https://stat.ethz.ch/pipermail/bioc-devel/2020-April/016656.html
)
```

# Setup

```{r, message = FALSE}
library(BioPlex)
library(AnnotationDbi)
library(AnnotationHub)
library(graph)
```

Connect to 
[AnnotationHub](http://bioconductor.org/packages/AnnotationHub):

```{r ahub, message = FALSE}
ah <- AnnotationHub::AnnotationHub()
```

Connect to 
[ExperimentHub](http://bioconductor.org/packages/ExperimentHub):

```{r ehub, message = FALSE}
eh <- ExperimentHub::ExperimentHub()
```

OrgDb package for human:
```{r orgdb, message = FALSE}
orgdb <- AnnotationHub::query(ah, c("orgDb", "Homo sapiens"))
orgdb <- orgdb[[1]]
orgdb
keytypes(orgdb)
```

# Check: identify CORUM complexes that have a subunit of interest

Get core set of complexes:
```{r corumCore}
core <- getCorum(set = "core", organism = "Human")
```

Turn the CORUM complexes into a list of graph instances,
where all nodes of a complex are connected to all other nodes of that complex
with undirected edges.

```{r corum2glist}
core.glist <- corum2graphlist(core, subunit.id.type = "UNIPROT")
```

Identify complexes that have a subunit of interest:
```{r corum-subunit}
has.cdk2 <- hasSubunit(core.glist, 
                       subunit = "CDK2",
                       id.type = "SYMBOL")
```

Check the answer:
```{r corum-subunit2}
table(has.cdk2)
cdk2.glist <- core.glist[has.cdk2]
lapply(cdk2.glist, function(g) unlist(graph::nodeData(g, attr = "SYMBOL")))
```

We can then also inspect the graph with plotting utilities from the 
[Rgraphviz](https://bioconductor.org/packages/Rgraphviz)
package:

```{r corum-subunit3, message = FALSE, eval = FALSE}
plot(cdk2.glist[[1]], main = names(cdk2.glist)[1])
```

# Check: extract BioPlex PPIs for a CORUM complex

Get the latest version of the 293T PPI network:

```{r bioplex293T}
bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")
```

Turn the BioPlex PPI network into one big graph where bait and prey relationship
are represented by directed edges from bait to prey.

```{r bpgraph}
bp.gr <- bioplex2graph(bp.293t)
```

Now we can also easily pull out a BioPlex subnetwork for a CORUM complex
of interest:

```{r}
n <- graph::nodes(cdk2.glist[[1]])
bp.sgr <- graph::subGraph(n, bp.gr)
bp.sgr
```

# Check: identify interacting domains for a PFAM domain of interest

Add PFAM domain annotations to the node metadata:

```{r}
bp.gr <- BioPlex::annotatePFAM(bp.gr, orgdb)
```

Create a map from PFAM to UNIPROT:

```{r}
unip2pfam <- graph::nodeData(bp.gr, graph::nodes(bp.gr), "PFAM")
pfam2unip <- stack(unip2pfam)
pfam2unip <- split(as.character(pfam2unip$ind), pfam2unip$values)
head(pfam2unip, 2)
```

Let's focus on [PF02023](http://pfam.xfam.org/family/PF02023), corresponding to the
zinc finger-associated SCAN domain. For each protein containing the SCAN domain,
we now extract PFAM domains connected to the SCAN domain by an edge in the BioPlex network.

```{r}
scan.unip <- pfam2unip[["PF02023"]]
getIAPfams <- function(n) graph::nodeData(bp.gr, graph::edges(bp.gr)[[n]], "PFAM")
unip2iapfams <- lapply(scan.unip, getIAPfams)
unip2iapfams <- lapply(unip2iapfams, unlist)
names(unip2iapfams) <- scan.unip
```

Looking at the top 5 PFAM domains most frequently connected to the SCAN domain 
by an edge in the BioPlex network ...

```{r}
pfam2iapfams <- unlist(unip2iapfams)
sort(table(pfam2iapfams), decreasing = TRUE)[1:5]
```

... we find [PF02023](http://pfam.xfam.org/family/PF02023), the SCAN domain itself,
and [PF00096](http://pfam.xfam.org/family/PF00096), a C2H2 type zinc finger domain.
This finding is consistent with results reported in the
[BioPlex 3.0 publication](https://doi.org/10.1016/j.cell.2021.04.011).


See also the 
[PFAM domain-domain association analysis vignette](https://ccb-hms.github.io/BioPlexAnalysis/articles/PFAM.html)
for a more comprehensive analysis of PFAM domain associations in the BioPlex network.

# Check: agreement between CNV tracks

Genomic data from whole-genome sequencing for six different lineages
of the human embryonic kidney HEK293 cell line can be obtained from
[hek293genome.org](http://hek293genome.org).

This includes copy number variation (CNV) data for the 293T cell line.
Available CNV tracks include (i) CNV regions inferred from sequencing 
read-depth analysis, and (ii) CNV regions inferred from Illumina SNP arrays.

Here, we check agreement between inferred copy numbers from both assay types.

We start by obtaining genomic coordinates and copy number scores from the sequencing
track ...
 
```{r cnv-seq}
cnv.hmm <- getHEK293GenomeTrack(track = "cnv.hmm", cell.line = "293T")
cnv.hmm
```

... and from the SNP track.

```{r cnv-snp}
cnv.snp <- getHEK293GenomeTrack(track = "cnv.snp", cell.line = "293T")
cnv.snp
```

We reduce the check for agreement between both CNV tracks by transferring copy
numbers to overlapping genes, and subsequently, assess the agreement between the
resulting gene copy numbers for both tracks.  

As the genomic coordinates from both CNV tracks is based on the hg18 human genome 
assembly, we obtain gene coordinates for hg18 from AnnotationHub:

```{r hg18-genes}
AnnotationHub::query(ah, c("TxDb", "Homo sapiens"))
txdb <- ah[["AH52257"]]
gs <- GenomicFeatures::genes(txdb)
gs
```

We then transfer SNP-inferred copy numbers to genes by overlap ...

```{r}
olaps <- GenomicRanges::findOverlaps(gs, cnv.snp)
joined <- gs[S4Vectors::queryHits(olaps)]
joined$score <- cnv.snp$score[S4Vectors::subjectHits(olaps)]
joined
```

... and, analogously, transfer sequencing-inferred copy numbers to genes by overlap.

```{r}
olaps <- GenomicRanges::findOverlaps(gs, cnv.hmm)
joined2 <- gs[S4Vectors::queryHits(olaps)]
joined2$score <- cnv.hmm$score[S4Vectors::subjectHits(olaps)]
joined2
```

We then restrict both tracks to common genes.

```{r}
isect <- intersect(names(joined), names(joined2))
joined <- joined[isect]
joined2 <- joined2[isect]
```

Now, can assess agreement by testing the correlation between SNP-inferred gene
copy numbers and the corresponding sequencing-inferred gene copy numbers. 

```{r}
cor(joined$score, joined2$score)
cor.test(joined$score, joined2$score)
```

We also inspect the correlation via a boxplot.

```{r, fig.width = 8, fig.height = 8}
spl <- split(joined2$score, joined$score)
boxplot(spl, xlab = "SNP-inferred copy number", ylab = "sequencing-inferred copy number")
rho <- cor(joined$score, joined2$score)
rho <- paste("cor", round(rho, digits=3), sep=" = ")

p <- cor.test(joined$score, joined2$score)
p <- p$p.value
p <- "   p < 2.2e-16"

legend("topright", legend=c(rho, p))
```


# Check: expressed genes are showing up as prey (293T cells)

Get RNA-seq data for HEK293 cells from GEO: 
[GSE122425](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE122425)

```{r gse122425}
se <- getGSE122425()
se
```

Inspect expression of prey genes:

```{r prey-expression}
bait <- unique(bp.293t$SymbolA)
length(bait)
prey <- unique(bp.293t$SymbolB)
length(prey)
```

```{r}
ind <- match(prey, rowData(se)$SYMBOL)
par(las = 2)
boxplot(log2(assay(se, "rpkm") + 0.5)[ind,], 
        names = se$title, 
        ylab = "log2 RPKM")
```

How many prey genes are expressed (raw read count > 0) in all 3 WT reps:

```{r prey-expression2}
# background: how many genes in total are expressed in all three WT reps
gr0 <- rowSums(assay(se)[,1:3] > 0)
table(gr0 == 3)
# prey: expressed in all three WT reps
table(gr0[ind] == 3)
# prey: expressed in at least one WT rep
table(gr0[ind] > 0)
```

Are prey genes overrepresented in the expressed genes?
```{r prey-expression-ora}
exprTable <-
     matrix(c(9346, 1076, 14717, 32766),
            nrow = 2,
            dimnames = list(c("Expressed", "Not.expressed"),
                            c("In.prey.set", "Not.in.prey.set")))
exprTable
```

Test using hypergeometric test (i.e. one-sided Fisher's exact test):
```{r prey-expression-ora2}
fisher.test(exprTable, alternative = "greater")
```

Alternatively: permutation test, i.e. repeatedly sample number of prey genes 
from the background, and assess how often we have as many or more than 9346 genes
expressed:

```{r prey-expression-293T-perm}
permgr0 <- function(gr0, nr.genes = length(prey)) 
{
    ind <- sample(seq_along(gr0), nr.genes)
    sum(gr0[ind] == 3)
}
```

```{r prey-expression-perm2}
perms <- replicate(permgr0(gr0), 1000)
summary(perms)
(sum(perms >= 9346) + 1) / 1001
```

# Check: is there a relationship between prey frequency and prey expression level?

Check which genes turn up most frequently as prey:

```{r prey-freq}
prey.freq <- sort(table(bp.293t$SymbolB), decreasing = TRUE)
preys <- names(prey.freq)
prey.freq <- as.vector(prey.freq)
names(prey.freq) <- preys
head(prey.freq)
summary(prey.freq)
hist(prey.freq, breaks = 50, main = "", xlab = "Number of PPIs", ylab = "Number of genes")
```

Prey genes are involved in `r round(mean(as.vector(prey.freq)))` PPIs on average.

There doesn't seem to be a strong correlation between expression level and the 
frequency of gene to turn up as prey: 

```{r}
ind <- match(names(prey.freq), rowData(se)$SYMBOL)
rmeans <- rowMeans(assay(se, "rpkm")[ind, 1:3])
log.rmeans <- log2(rmeans + 0.5)
par(pch = 20)
plot( x = prey.freq,
      y = log.rmeans,
      xlab = "prey frequency",
      ylab = "log2 RPKM")
cor(prey.freq, 
    log.rmeans,
    use = "pairwise.complete.obs")
```

See also the [BioNet maximum scoring subnetwork analysis vignette](https://ccb-hms.github.io/BioPlexAnalysis/articles/BioNet.html) 
for a more comprehensive analysis of the 293T transcriptome data from GSE122425
when mapped onto BioPlex PPI network.

# Check: differential protein expression (HEK293 vs. HCT116)  

Get the relative protein expression data comparing 293T and HCT116 cells
from Supplementary Table S4A of the BioPlex 3 paper:

```{r bp.prot}
bp.prot <- getBioplexProteome()
bp.prot
rowData(bp.prot)
```

A couple of quick sanity checks:

1. The relative abundances are scaled to sum up to 100% for each protein:

```{r}
rowSums(assay(bp.prot)[1:5,]) 
```

2. The `rowData` column `log2ratio` corresponds to the mean of the five HEK samples, 
divided by the mean of the five HCT samples (and then taking log2 of it):

```{r}
ratio <- rowMeans(assay(bp.prot)[1:5, 1:5]) / rowMeans(assay(bp.prot)[1:5, 6:10])
log2(ratio)
```

3. The `rowData` column `adj.pvalue` stores Benjamini-Hochberg adjusted *p*-values
from a *t*-test between the five HEK samples and the five HCT samples:

```{r}
t.test(assay(bp.prot)[1, 1:5], assay(bp.prot)[1, 6:10])
```

The [Transcriptome-Proteome analysis vignette](https://ccb-hms.github.io/BioPlexAnalysis/articles/TranscriptomeProteome.html) also explores the agreement between differential gene expression and 
differential protein expression when comparing HEK293 against HCT116 cells.

# SessionInfo

```{r sessionInfo}
sessionInfo()
```

---
title: "Import and representation of BioPlex PPI data and related resources"
author: "Ludwig Geistlinger and Robert Gentleman"
affiliation: Center for Computational Biomedicine, Harvard Medical School
output:
  BiocStyle::html_document:
    self_contained: yes 
    toc: true
    toc_float: true
    toc_depth: 2
    code_folding: show
date: "`r doc_date()`"
package: "`r pkg_ver('BioPlex')`"
vignette: >
  % \VignetteIndexEntry{1. Data retrieval}
  % \VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
    collapse = TRUE,
    comment = "#>",
    crop = NULL ## Related to https://stat.ethz.ch/pipermail/bioc-devel/2020-April/016656.html
)
```

# Setup

The [BioPlex project](https://bioplex.hms.harvard.edu/) uses 
affinity-purification mass spectrometry to profile protein-protein interactions (PPIs)
in human cell lines.

To date, the BioPlex project has created two proteome-scale, cell-line-specific 
PPI networks. The first, BioPlex 3.0, results from affinity purification of 
10,128 human proteins —- half the proteome —- in 293T cells and includes 118,162
interactions among 14,586 proteins. 
The second results from 5,522 immunoprecipitations in HCT116 cells and includes
70,966 interactions between 10,531 proteins. 

For more information, please see:

* Huttlin et al. [The BioPlex network: a systematic exploration of the human interactome](https://doi.org/10.1016/j.cell.2015.06.043). *Cell*, 2015.
* Huttlin et al. [Architecture of the human interactome defines protein communities and disease networks](https://doi.org/10.1038/nature22366), *Nature*, 2017.
* Huttlin et al. [Dual proteome-scale networks reveal cell-specific remodeling of the human interactome](https://doi.org/10.1016/j.cell.2021.04.011), *Cell*, 2021.

The [BioPlex R package](https://bioconductor.org/packages/BioPlex) 
implements access to the BioPlex protein-protein interaction networks and 
related resources from within R. 
Besides protein-protein interaction networks for 293T and HCT116 cells,
this includes access to [CORUM](http://mips.helmholtz-muenchen.de/corum)
protein complex data, and transcriptome and proteome data for the two cell lines. 
             
Functionality focuses on importing these data resources and
storing them in dedicated Bioconductor data structures, as a foundation for 
integrative downstream analysis of the data. For a set of downstream analyses
and applications, please see the 
[BioPlexAnalysis package](https://github.com/ccb-hms/BioPlexAnalysis)
and 
[analysis vignettes](https://ccb-hms.github.io/BioPlexAnalysis/).

# Installation

To install the package, start R and enter: 

```{r, eval = FALSE}
if(!requireNamespace("BiocManager", quietly = TRUE))
    install.packages("BiocManager")
BiocManager::install("BioPlex")
``` 

After the installation, we proceed by loading the package and additional packages
used in the vignette.

```{r, message = FALSE}
library(BioPlex)
library(AnnotationHub)
library(ExperimentHub)
library(graph)
```

# Data resources

## General

Connect to 
[AnnotationHub](http://bioconductor.org/packages/AnnotationHub):

```{r ahub, message = FALSE}
ah <- AnnotationHub::AnnotationHub()
```

Connect to 
[ExperimentHub](http://bioconductor.org/packages/ExperimentHub):

```{r ehub, message = FALSE}
eh <- ExperimentHub::ExperimentHub()
```

OrgDb package for human:
```{r orgdb, message = FALSE}
orgdb <- AnnotationHub::query(ah, c("orgDb", "Homo sapiens"))
orgdb <- orgdb[[1]]
orgdb
keytypes(orgdb)
```

## BioPlex PPIs

[Available networks](https://bioplex.hms.harvard.edu/interactions.php) include: 

- BioPlex PPI network for human embryonic kidney [293T](https://en.wikipedia.org/wiki/293T) cells (versions 1.0, 2.0, and 3.0)
- BioPlex PPI network for human colon cancer [HCT116](https://en.wikipedia.org/wiki/HCT116_cells) cells (version 1.0)

Let's get the latest version of the 293T PPI network:

```{r bioplex293T}
bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")
head(bp.293t)
nrow(bp.293t)
```

Each row corresponds to a PPI between a bait protein A and a prey protein B, for which
NCBI Entrez Gene IDs, Uniprot IDs, and gene symbols are annotated. 
The last three columns reflect the likelihood that each interaction resulted 
from either an incorrect protein identification (`pW`), background (`pNI`), or 
a bona fide interacting partner (`pInt`) as determined using the 
[CompPASS algorithm](https://github.com/dnusinow/cRomppass).

Analgously, we can obtain the latest version of the HCT116 PPI network:

```{r bioplexHCT116}
bp.hct116 <- getBioPlex(cell.line = "HCT116", version = "1.0")
head(bp.hct116)
nrow(bp.hct116)
```

### ID mapping

The protein-to-gene mappings from BioPlex (i.e. UNIPROT-to-SYMBOL and UNIPROT-to-ENTREZID) are based on the mappings available from Uniprot at the time of publication of the BioPlex 3.0 networks.

We can update those based on Bioc annotation functionality:  

```{r bioplex-remap}
bp.293t.remapped <- getBioPlex(cell.line = "293T",
                               version = "3.0",
                               remap.uniprot.ids = TRUE)
```

### Data structures for BioPlex PPIs

We can also represent a given version of the BioPlex PPI network for a given
cell line as one big graph where bait and prey relationship are represented 
by directed edges from bait to prey.

```{r bpgraph}
bp.gr <- bioplex2graph(bp.293t)
bp.gr
head(graph::nodeData(bp.gr))
head(graph::edgeData(bp.gr))
```

### PFAM domains

We can easily add [PFAM](http://pfam.xfam.org) domain annotations to the node metadata:

```{r pfam}
bp.gr <- annotatePFAM(bp.gr, orgdb)
head(graph::nodeData(bp.gr, graph::nodes(bp.gr), "PFAM"))
```

## CORUM complexes

Obtain the complete set of human protein complexes from
[CORUM](http://mips.helmholtz-muenchen.de/corum/#download):

```{r corumALL}
all <- getCorum(set = "all", organism = "Human")
dim(all)
colnames(all)
all[1:5, 1:5]
```

Core set of complexes:
```{r corumCore}
core <- getCorum(set = "core", organism = "Human")
dim(core)
```

Complexes with splice variants:
```{r corumSplice}
splice <- getCorum(set = "splice", organism = "Human")
dim(splice)
```

### ID mapping

The protein-to-gene mappings from CORUM (i.e. UNIPROT-to-SYMBOL and UNIPROT-to-ENTREZID) might not be fully up-to-date. 

We can update those based on Bioc annotation functionality:  

```{r corum-remap}
core.remapped <- getCorum(set = "core", 
                          organism = "Human",
                          remap.uniprot.ids = TRUE)
```

### Data structures for CORUM complexes 

We can represent the CORUM complexes as a list of character vectors.
The names of the list are the complex IDs/names, and each element of the list is
a vector of UniProt IDs for each complex.

```{r corum2list}
core.list <- corum2list(core, subunit.id.type = "UNIPROT")
head(core.list)
length(core.list)
```

We can also represent the CORUM complexes as a list of graph instances,
where all nodes of a complex are connected to all other nodes of that complex
with undirected edges.

```{r corum2glist}
core.glist <- corum2graphlist(core, subunit.id.type = "UNIPROT")
head(core.glist)
length(core.glist)
core.glist[[1]]@graphData
graph::nodeData(core.glist[[1]])
```

Note that we can easily convert a 
[graph](https://bioconductor.org/packages/graph) object into an 
[igraph](https://cran.r-project.org/package=igraph) object using
`igraph::graph_from_graphnel`.

## CNV data

### HEK293T cells

Genomic data from whole-genome sequencing for six different lineages
of the human embryonic kidney HEK293 cell line can be obtained from
[hek293genome.org](http://hek293genome.org).

This includes copy number variation (CNV) data for the 293T cell line.
Available CNV tracks include (i) CNV regions inferred from sequencing 
read-depth analysis, and (ii) CNV regions inferred from Illumina SNP arrays.

Here, we obtain CNV segments obtained from applying a hidden Markov model (HMM)
to sequencing-inferred copy numbers in 2kbp windows. More details on how copy
numbers were calculated can be obtained from the 
[primary publication](https://doi.org/10.1038/ncomms5767). 

```{r cnv}
cnv.hmm <- getHEK293GenomeTrack(track = "cnv.hmm", cell.line = "293T")
cnv.hmm
```

See also the [data checks vignette, Section 5](
https://bioconductor.org/packages/release/data/experiment/vignettes/BioPlex/inst/doc/BasicChecks.html) for an exploration of the agreement between inferred copy numbers from both assay types (SNP arrays vs. sequencing).

## Transcriptome data

### HEK293T cells

#### GSE122425

Obtain transcriptome data for 293T cells from GEO dataset:
[GSE122425](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE122425).

```{r gse122425}
se <- getGSE122425()
se
head(assay(se, "raw"))
head(assay(se, "rpkm"))
colData(se)
rowData(se)
```

The dataset includes three wild type samples and three NSUN2 knockout samples.

See also the [data checks vignette, Section 7](https://bioconductor.org/packages/release/data/experiment/vignettes/BioPlex/inst/doc/BasicChecks.html) for an exploration of the relationship between expression level and the frequency of a protein being detected as prey. 

### HCT116 cells

#### Cancer Cell Line Encyclopedia (CCLE)

RNA-seq data for 934 cancer cell lines (incl. HCT116) from the 
[Cancer Cell Line Encyclopedia](https://portals.broadinstitute.org/ccle) 
is available from the [ArrayExpress-ExpressionAtlas](https://www.ebi.ac.uk/gxa) 
(Accession: [E-MTAB-2770](https://www.ebi.ac.uk/gxa/experiments/E-MTAB-2770)).

The data can be obtained as a `SummarizedExperiment` using the 
[ExpressionAtlas](https://bioconductor.org/packages/ExpressionAtlas) package.

```{r, eval = FALSE}
ccle.trans <- ExpressionAtlas::getAtlasExperiment("E-MTAB-2770")
```

See also the [Transcriptome-Proteome analysis vignette](https://ccb-hms.github.io/BioPlexAnalysis/articles/TranscriptomeProteome.html) 
for further exploration of the correlation between CCLE HCT116 transcript and
protein expression. 


#### Klijn et al., 2015

RNA-seq data of 675 commonly used human cancer cell lines (incl. HCT116) from 
[Klijn et al., 2015](https://pubmed.ncbi.nlm.nih.gov/25485619) 
is available from the [ArrayExpress-ExpressionAtlas](https://www.ebi.ac.uk/gxa) 
(Accession: [E-MTAB-2706](https://www.ebi.ac.uk/gxa/experiments/E-MTAB-2706))

The data can be obtained as a `SummarizedExperiment` using the 
[ExpressionAtlas](https://bioconductor.org/packages/ExpressionAtlas) package.

```{r, eval = FALSE}
klijn <- ExpressionAtlas::getAtlasExperiment("E-MTAB-2706")
```

See also the [Transcriptome-Proteome analysis vignette](https://ccb-hms.github.io/BioPlexAnalysis/articles/TranscriptomeProteome.html) 
for further exploration of differential transcript and
protein expression between 293T and HCT116 cells. 

## Splicing data

For the inference of differential exon usage between cell lines, raw RNA-seq read
counts on exon level can be obtained from
[ExperimentHub](https://bioconductor.org/packages/ExperimentHub).   

RNA-seq data for 293T cells was obtained from GEO accession
[GSE122633](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE122633) and
RNA-seq data for HCT116 cells was obtained from GEO accession
[GSE52429](https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE52429). 

The data can be obtained as a `DEXSeqDataSet` which is a
`SummarizedExperiment`-derivative and can be accessed and manipulated very much
like a `DESeqDataSet`.

```{r splice, message = FALSE}
AnnotationHub::query(eh, c("BioPlex"))
dex <- eh[["EH7563"]]
dex
```

We take a closer look at the sample annotation, the counts for each exon for
both cell lines, and the genomic coordinates and additional annotation for each
exon.

```{r}
DEXSeq::sampleAnnotation(dex)
head(DEXSeq::featureCounts(dex))
rowRanges(dex)
```

## Proteome data

### CCLE

Pull the [CCLE proteome data](https://doi.org/10.1016/j.cell.2019.12.023) from ExperimentHub. The dataset profiles 12,755 proteins by mass spectrometry across 375 cancer cell lines.

```{r ccle-proteom, message = FALSE}
AnnotationHub::query(eh, c("gygi", "depmap"))
ccle.prot <- eh[["EH3459"]]
ccle.prot <- as.data.frame(ccle.prot)
```

Explore the data:
```{r ccle-proteom2}
dim(ccle.prot)
colnames(ccle.prot)
head(ccle.prot)
```

Restrict to HCT116:

```{r ccle-prot-hct116}
ccle.prot.hct116 <- subset(ccle.prot, cell_line == "HCT116_LARGE_INTESTINE")
dim(ccle.prot.hct116)
head(ccle.prot.hct116)
```

Or turn into a `SummarizedExperiment` for convenience (we can restrict
this to selected cell lines, but here we keep all cell lines):

```{r ccle-prot-se}
se <- ccleProteome2SummarizedExperiment(ccle.prot, cell.line = NULL)
assay(se)[1:5, 1:5]
assay(se)[1:5, "HCT116"]
rowData(se)
```

### Relative protein expression data from BioPlex3.0

The [BioPlex 3.0 publication](https://doi.org/10.1016/j.cell.2021.04.011), 
Supplementary Table S4A, provides relative protein expression data comparing
293T and HCT116 cells based on tandem mass tag analysis.

```{r bp.prot}
bp.prot <- getBioplexProteome()
assay(bp.prot)[1:5,1:5]
colData(bp.prot)
rowData(bp.prot)
```

The data contains 5 replicates each for 293T and for HCT116 cells.
As a result of the data collection process, the data represent relative protein abundance 
scaled to add up to 100% in each row.

See also the [data checks vignette, Section 8](https://bioconductor.org/packages/release/data/experiment/vignettes/BioPlex/inst/doc/BasicChecks.html) for a basic exploration of the annotated differential expression measures.

# Caching

Note that calling functions like `getCorum` or `getBioPlex` with argument
`cache = FALSE` will automatically overwrite the corresponding object in your 
cache. It is thus typically not required for a user to interact with the cache.

For more extended control of the cache, use from within R:

```{r cache}
cache.dir <- tools::R_user_dir("BioPlex", which = "cache") 
bfc <- BiocFileCache::BiocFileCache(cache.dir)
```

and then proceed as described in the
[BiocFileCache vignette, Section 1.10](https://www.bioconductor.org/packages/release/bioc/vignettes/BiocFileCache/inst/doc/BiocFileCache.html#cleaning-or-removing-cache)
either via `cleanbfc()` to clean or `removebfc()` to remove your cache.

To do a hard reset (use with caution!):

```{r rmCache, eval = FALSE}
BiocFileCache::removebfc(bfc)
```

# SessionInfo

```{r sessionInfo}
sessionInfo()
```

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bioplex.R
\name{getBioPlex}
\alias{getBioPlex}
\title{Obtain BioPlex protein-protein interaction data}
\usage{
getBioPlex(
  cell.line = c("293T", "HCT116"),
  version = c("3.0", "1.0", "2.0"),
  remap.uniprot.ids = FALSE,
  cache = TRUE
)
}
\arguments{
\item{cell.line}{character. Valid options include:
\itemize{
\item \code{"293T"}: derivative of human embryonic kidney 293 cell line,
\item \code{"HCT116"}: human colon cancer cell line 116.
}
Defaults to \code{"293T"}.}

\item{version}{character. Valid options include \code{"1.0"}, \code{"2.0"},
and \code{"3.0"} for 293T cells. For HCT116 cells, only \code{"1.0"} is
available.
Defaults to \code{"3.0"}.}

\item{remap.uniprot.ids}{logical. Should the protein-to-gene mappings from BioPlex
(i.e. UNIPROT-to-SYMBOL and UNIPROT-to-ENTREZID) be updated using Bioc annotation
functionality?
Defaults to \code{FALSE} which will then keep the mappings provided by BioPlex.}

\item{cache}{logical. Should a locally cached version used if available?
Defaults to \code{TRUE}.}
}
\value{
A \code{data.frame}.
}
\description{
Functionality for retrieving the BioPlex protein-protein
interaction data. Available networks include:
\itemize{
\item BioPlex 293T cells (versions 1.0, 2.0, and 3.0),
\item BioPlex HCT116 cells (version 1.0).
} See references.
}
\examples{
# (1) Obtain the latest version of the 293T PPI network
bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")

# (2) Obtain the latest version of the HCT116 PPI network
bp.hct116 <- getBioPlex(cell.line = "HCT116", version = "1.0")
}
\references{
BioPlex: \url{https://bioplex.hms.harvard.edu/interactions.php}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bioplex.R
\name{mapSummarizedExperimentOntoGraph}
\alias{mapSummarizedExperimentOntoGraph}
\title{Map experimental data onto a graph}
\usage{
mapSummarizedExperimentOntoGraph(
  gr,
  se,
  col.names = NULL,
  rowdata.cols = NULL,
  prefix = ""
)
}
\arguments{
\item{gr}{an object of class \code{\linkS4class{graph}}.}

\item{se}{an object of class \code{\linkS4class{SummarizedExperiment}}.}

\item{col.names}{character. Column names of \code{se} for which assay
data should be mapped onto the nodes of \code{gr}. Defaults to \code{NULL}
which will then use all column names of \code{se}.}

\item{rowdata.cols}{character. Column names of \code{rowData(se)} which
should be mapped onto the nodes of \code{gr}. Defaults to \code{NULL}
which will then use all column names of \code{rowData(se)}.}

\item{prefix}{character. Informative prefix that should be pasted together
with the selected \code{col.names} and \code{rowdata.cols} to allow easy
identification of columns of interest when mapping from multiple experimental
datasets.}
}
\value{
An object of class \code{\linkS4class{graph}}.
}
\description{
Functionality for mapping experimental data stored in
a \code{\linkS4class{SummarizedExperiment}} onto a
\code{\linkS4class{graph}} object.
}
\examples{
# (1) Obtain the latest version of the 293T PPI network ...
bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")

# (2) ... and turn into a graph
bp.gr <- bioplex2graph(bp.293t)

# (3) Obtain the BioPlex3 proteome data ...
se <- getBioplexProteome()

# (4) ... and map onto the graph
bp.gr <- mapSummarizedExperimentOntoGraph(bp.gr, se)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corum.R
\name{corum2list}
\alias{corum2list}
\title{Represent CORUM protein complex data as a simple list}
\usage{
corum2list(corum.df, subunit.id.type = c("UNIPROT", "ENTREZID"))
}
\arguments{
\item{corum.df}{A \code{data.frame} storing the CORUM protein complex data.
Typically obtained via \code{\link{getCorum}}.}

\item{subunit.id.type}{character. Supported options include \code{"UNIPROT"}
(default) and \code{"ENTREZID"}.}
}
\value{
A \code{list} with an entry for each complex. Each entry is a
character vector of subunit IDs.
}
\description{
Functionality for storing CORUM protein complex data in a
\code{list}.
}
\examples{
 # (1) Obtain the core set of CORUM complexes ...
 core <- getCorum(set = "core")
 
 # (2) ... turn into a list
 core.list <- corum2list(core)
}
\references{
CORUM: \url{http://mips.helmholtz-muenchen.de/corum/#download}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bioplex.R
\name{annotatePFAM}
\alias{annotatePFAM}
\title{Annotate PFAM domains to BioPlex PPI graph}
\usage{
annotatePFAM(bp.gr, orgdb)
}
\arguments{
\item{bp.gr}{an object of class \code{\linkS4class{graph}} storing the
BioPlex PPIs. Typically obtained via \code{\link{bioplex2graph}}.}

\item{orgdb}{an \code{orgdb} object storing annotation data for human.}
}
\value{
An object of class \code{graphNEL} containing PFAM domain annotations
in the \code{nodeData}.
}
\description{
This function adds PFAM domain annotations to the node metadata
of the BioPlex PPI graph.
}
\examples{
# (1) Obtain the latest version of the 293T PPI network
bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")

# (2) Turn the data into a graph 
bp.gr <- bioplex2graph(bp.293t)

# (3) Obtain orgdb package from AnnotationHub
ah <- AnnotationHub::AnnotationHub()
orgdb <- AnnotationHub::query(ah, c("orgDb", "Homo sapiens"))
orgdb <- orgdb[[1]]

# (4) Annotate PFAM domains
bp.gr <- annotatePFAM(bp.gr, orgdb)

}
\references{
BioPlex: \url{https://bioplex.hms.harvard.edu/interactions.php}

PFAM: \url{http://pfam.xfam.org}
}
\seealso{
\code{\link{nodeData}}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/proteome.R
\name{ccleProteome2SummarizedExperiment}
\alias{ccleProteome2SummarizedExperiment}
\title{Convenient access to the CCLE proteome data}
\usage{
ccleProteome2SummarizedExperiment(df, cell.line = "HCT116")
}
\arguments{
\item{df}{a \code{data.frame} storing the CCLE protein expression data with
one measurement in each row. Typically obtained from \code{ExperimentHub}.
See examples.}

\item{cell.line}{character. One or more cell line IDs such as \code{"HCT116"}
(human colon cancer cell line 116). Use \code{NULL} to not subset by cell line.
Defaults to \code{"HCT116"}, which will then subset the df to measurements for
HCT116 only.}
}
\value{
A \code{\linkS4class{SummarizedExperiment}} storing protein expression
data for the specified cell line(s).
}
\description{
Functionality for storing the protein expression data
from the Cancer Cell Line Encyclopedia (CCLE) in a
\code{\linkS4class{SummarizedExperiment}}.
}
\examples{

  # Connect to ExperimentHub
  eh <- ExperimentHub::ExperimentHub()

  # Obtain CCLE proteome data frame
  AnnotationHub::query(eh, c("gygi", "depmap"))
  ccle.prot <- eh[["EH3459"]]
  ccle.prot <- as.data.frame(ccle.prot)

  # Turn into a SummarizedExperiment
  se <- ccleProteome2SummarizedExperiment(ccle.prot)
  
}
\references{
CCLE proteomics: \url{https://gygi.hms.harvard.edu/publications/ccle.html}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/proteome.R
\name{getBioplexProteome}
\alias{getBioplexProteome}
\title{Obtain BioPlex3 proteome data}
\usage{
getBioplexProteome(cache = TRUE)
}
\arguments{
\item{cache}{logical. Should a locally cached version used if available?
Defaults to \code{TRUE}.}
}
\value{
A \code{\linkS4class{SummarizedExperiment}} storing protein expression
data for the both cell line(s) with 5 replicates each.
}
\description{
Functionality for retrieving the BioPlex3 protein expression
data comparing expression in the HCT116 and the 293T cell lines.
}
\examples{

  se <- getBioplexProteome()
  
}
\references{
BioPlex: \url{https://bioplex.hms.harvard.edu}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corum.R
\name{corum2graphlist}
\alias{corum2graphlist}
\title{Represent CORUM protein complex data as a list of graph instances}
\usage{
corum2graphlist(corum.df, subunit.id.type = c("UNIPROT", "ENTREZID"))
}
\arguments{
\item{corum.df}{A \code{data.frame} storing the CORUM protein complex data.
Typically obtained via \code{\link{getCorum}}.}

\item{subunit.id.type}{character. Supported options include \code{"UNIPROT"}
(default) and \code{"ENTREZID"}.}
}
\value{
A \code{list} with an entry for each complex. Each entry is an
object of class \code{graphNEL} connecting all subunit IDs with each other
by undirected edges.
}
\description{
Functionality for storing CORUM protein complex data in a
\code{list} of \code{graph} instances.
}
\examples{
 # (1) Obtain the core set of CORUM complexes ...
 core <- getCorum(set = "core")
 
 # (2) ... turn into a list of graphs
 core.glist <- corum2graphlist(core)
}
\references{
CORUM: \url{http://mips.helmholtz-muenchen.de/corum/#download}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cnv.R
\name{getHEK293GenomeTrack}
\alias{getHEK293GenomeTrack}
\title{Obtain HEK293 genome data}
\usage{
getHEK293GenomeTrack(
  track = c("cnv.hmm", "cnv.snp"),
  cell.line = "293T",
  cache = TRUE
)
}
\arguments{
\item{track}{character. Genome track to retrieve. Valid options include:
\itemize{
\item \code{"cnvhmm"}: regions of copy number variation (CNV) as inferred by
a hidden Markov model (HMM) algorithm,
\item \code{"cnvsnp"}: CNV regions as inferred from Illumina SNP arrays
}
Defaults to \code{"cnvhmm"}.}

\item{cell.line}{character. Valid options include:
\itemize{
\item \code{"293T"}: highly-transfective derivative of human embryonic kidney
293 cell line,
}
Defaults to \code{"293T"}.}

\item{cache}{logical. Should a locally cached version used if available?
Defaults to \code{TRUE}.}
}
\value{
A \code{GRanges} object storing genomic coordinates and genomic scores
of regions of interest.
}
\description{
Functionality for retrieving genomic data for different
lineages of the human embryonic kidney HEK293 cell line.
Returned genomic coordinates are based on the \emph{hg18} human genome assembly.
See references.
}
\examples{
   cnv.hmm <- getHEK293GenomeTrack(track = "cnv.hmm", cell.line = "293T")

}
\references{
\url{http://hek293genome.org}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/geo.R
\name{getGSE122425}
\alias{getGSE122425}
\title{Convenient access to 293T transcriptome data from GEO}
\usage{
getGSE122425(cache = TRUE)
}
\arguments{
\item{cache}{logical. Should a locally cached version used if available?
Defaults to \code{TRUE}.}
}
\value{
A \code{\linkS4class{SummarizedExperiment}} storing RNA-seq
data for the 293T cell line.
}
\description{
Functionality for storing the 293T RNA-seq data
from GSE122425 in a
\code{\linkS4class{SummarizedExperiment}}. The dataset includes three
wild type samples and three NSUN2 knockout samples.
}
\examples{

  # Obtain the data as a SummarizedExperiment
  se <- getGSE122425()
 
}
\references{
GSE122425: \url{https://www.ncbi.nlm.nih.gov/geo/query/acc.cgi?acc=GSE122425}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corum.R
\name{hasSubunit}
\alias{hasSubunit}
\title{Identify CORUM complexes that have a subunit of interest}
\usage{
hasSubunit(glist, subunit, id.type = "SYMBOL")
}
\arguments{
\item{glist}{A \code{list} of \code{graph}s storing CORUM complexes.
Typically obtained via \code{\link{corum2graphlist}}.}

\item{subunit}{character. A gene ID corresponding to the subunit of interest.}

\item{id.type}{character. Gene ID type of the given subunit. Defaults to \code{"SYMBOL"}.}
}
\value{
A logical vector indicating which graphs have a node with the given
subunit.
}
\description{
Screens a \code{list} of \code{graph} instances storing
CORUM protein complex data for a subunit of choice.
}
\examples{
# (1) Obtain the core set of CORUM complexes ...
core <- getCorum(set = "core")

# (2) ... turn into a list of graphs ...
core.glist <- corum2graphlist(core)

# (3) .. check for a particular subunit of interest
has.cdk2 <- hasSubunit(core.glist, subunit = "CDK2")
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/corum.R
\name{getCorum}
\alias{getCorum}
\title{Obtain CORUM protein complex data}
\usage{
getCorum(
  set = c("all", "core", "splice"),
  organism = "Human",
  remap.uniprot.ids = FALSE,
  cache = TRUE,
  mode = c("ehub", "web")
)
}
\arguments{
\item{set}{character. Valid options include:
\itemize{
\item \code{"all"}: complete set of complexes,
\item \code{"core"}: core set of complexes,
\item \code{"splice"}: complexes with splice variants.
}
Defaults to \code{"all"}.}

\item{organism}{character. Use \code{NULL} to not subset by organism.
Defaults to \code{"Human"} which restricts the data to human protein complexes
only.}

\item{remap.uniprot.ids}{logical. Should the protein-to-gene mappings from CORUM
(i.e. UNIPROT-to-SYMBOL and UNIPROT-to-ENTREZID) be updated using Bioc annotation
functionality? Currently only supported in combination with \code{organism = "Human"}.
Defaults to \code{FALSE} which will then keep the mappings provided by CORUM.}

\item{cache}{logical. Should a locally cached version used if available?
Defaults to \code{TRUE}.}

\item{mode}{character. Should CORUM complexes be obtained from ExperimentHub
or via a web download from the CORUM homepage? Defaults to \code{"ehub"},
which will obtain the chosen complex set from ExperimentHub.}
}
\value{
A \code{data.frame}.
}
\description{
Functionality for retrieving the CORUM protein complex data.
Available complex collections include:
\itemize{
\item complete set of complexes,
\item core set of complexes,
\item complexes with splice variants.
} See references.
}
\examples{
# Obtain the core set of CORUM complexes
core <- getCorum(set = "core")
}
\references{
CORUM: \url{http://mips.helmholtz-muenchen.de/corum/#download}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bioplex.R
\name{bioplex2graph}
\alias{bioplex2graph}
\title{Representation of BioPlex PPIs in a graph data structure}
\usage{
bioplex2graph(bioplex.df)
}
\arguments{
\item{bioplex.df}{a \code{data.frame} storing the Bioplex PPIs in a flat
from-to format. Typically obtained via \code{\link{getBioPlex}}.}
}
\value{
An object of class \code{graphNEL}.
}
\description{
Representation of BioPlex PPIs in a \code{graphNEL} object
from the \code{graph} package.
}
\examples{
# (1) Obtain the latest version of the 293T PPI network
bp.293t <- getBioPlex(cell.line = "293T", version = "3.0")

# (2) Turn the data into a graph 
bp.gr <- bioplex2graph(bp.293t)

}
\references{
BioPlex: \url{https://bioplex.hms.harvard.edu/interactions.php}
}
\seealso{
\code{\link{getBioPlex}}, \code{\link{ftM2graphNEL}}
}
